#!/usr/bin/env python

#   Gimp-Python - allows the writing of Gimp plugins in Python.
#   Copyright (C) 1997  James Henstridge <james@daa.com.au>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_bordersDR(image, layer, \
                    inner, inner_width, inner_height, inner_color, \
                    median, median_width, median_height, median_color, \
                    outer, outer_fill, outer_width, outer_height, outer_color):

    def create_border(name, width, height, color):
        old_width  = pdb.gimp_image_width(image)
        old_height = pdb.gimp_image_height(image)

        new_width = old_width+width*2
        new_height = old_height+height*2

        pdb.gimp_image_resize(image, new_width, new_height, width, height)

        border = gimp.Layer(image, name, new_width, new_height, RGBA_IMAGE,
                           100, NORMAL_MODE)
        pdb.gimp_image_add_layer(image, border, -1)
        pdb.gimp_edit_clear(border)

        pdb.gimp_rect_select(image, 0, 0, new_width, new_height, CHANNEL_OP_REPLACE,  0, 0.0)
        pdb.gimp_rect_select(image, width, height, old_width, old_height, CHANNEL_OP_SUBTRACT, 0, 0.0)

        pdb.gimp_context_set_foreground(color)
        pdb.gimp_edit_fill(border, FOREGROUND_FILL)

        pdb.gimp_selection_none(image)

    image.undo_group_start()

    old_color = pdb.gimp_context_get_foreground()

    if inner and (inner_width > 0 or inner_height > 0):
        create_border('Inner Border', inner_width, inner_height, inner_color)

    if median and (median_width > 0 or median_height > 0):
        create_border('Median Border', median_width, median_height, median_color)

    if outer and (outer_width > 0 or outer_height > 0):
        if not outer_fill:
            create_border('Outer Border', outer_width, outer_height, outer_color)
        else:
            old_width  = pdb.gimp_image_width(image)
            old_height = pdb.gimp_image_height(image)

            if outer_width > old_width or outer_height > old_height:
                create_border('Outer Border', max((outer_width-old_width)/2, 0), max((outer_height-old_height)/2, 0), outer_color)

    image.undo_group_end()

register(
        "python_fu_bordersDR",
        "Add inner, median and outer border for image",
        "Add inner, median and outer border for image",
        "Alexander Darovsky",
        "Alexander Darovsky",
        "2006-2007",
        "<Image>/Python-Fu/Decor/BordersDR",
        "RGB*",
        [
                (PF_BOOL,  "inner",        "Use inner border",    True),
                (PF_INT,   "inner_width",  "Inner Border Width",  1),
                (PF_INT,   "inner_height", "Inner Border Height", 1),
                (PF_COLOR, "inner_color",  "Inner Border Color",   (  0,  0,  0)),

                (PF_BOOL,  "median",        "Use Median border",    True),
                (PF_INT,   "median_width",  "Median Border Width",  1),
                (PF_INT,   "median_height", "Median Border Height", 1),
                (PF_COLOR, "median_color",  "Median Border Color", (255,255,255)),

                (PF_BOOL,  "outer",        "Use outer border",    True),
                (PF_BOOL,  "outer_fill",   "Outer border sizes are sizes of an image",    False),
                (PF_INT,   "outer_width",  "Outer Border Width",  20),
                (PF_INT,   "outer_height", "Outer Border Height", 20),
                (PF_COLOR, "outer_color",  "Outer Border Color",   (  0,  0,  0)),
        ],
        [],
        python_bordersDR)

main()
